aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/dax/dax-private.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/dax/dax-private.h')
-rw-r--r--drivers/dax/dax-private.h14
1 files changed, 5 insertions, 9 deletions
diff --git a/drivers/dax/dax-private.h b/drivers/dax/dax-private.h
index b1cd7a8e5ab9..b6fc4f04636d 100644
--- a/drivers/dax/dax-private.h
+++ b/drivers/dax/dax-private.h
@@ -38,22 +38,18 @@ struct dax_region {
};
/**
* struct dax_dev - subdivision of a dax region
* @region - parent region
- * @inode - inode
- * @dev - device backing the character device
- * @cdev - core chardev data
- * @alive - !alive + srcu grace period == no new mappings can be established
+ * @dax_dev - core dax functionality
+ * @dev - device core
* @id - child id in the region
* @num_resources - number of physical address extents in this device
* @res - array of physical address ranges
*/
-struct dax_dev {
+struct dev_dax {
struct dax_region *region;
- struct inode *inode;
+ struct dax_device *dax_dev;
struct device dev;
- struct cdev cdev;
- bool alive;
int id;
int num_resources;
struct resource res[0];
@@ -38,22 +38,18 @@ struct dax_region {
};
/**
- * struct dax_dev - subdivision of a dax region
+ * struct dev_dax - instance data for a subdivision of a dax region
* @region - parent region